[Openvas-commits] r1462 - in trunk/openvas-client: . include nessus
scm-commit@wald.intevation.org
scm-commit at wald.intevation.org
Mon Sep 29 00:49:29 CEST 2008
Author: jan
Date: 2008-09-29 00:49:28 +0200 (Mon, 29 Sep 2008)
New Revision: 1462
Removed:
trunk/openvas-client/include/config32.h
Modified:
trunk/openvas-client/ChangeLog
trunk/openvas-client/nessus/html_graph_output.c
trunk/openvas-client/nessus/html_output.c
trunk/openvas-client/nessus/latex_output.c
trunk/openvas-client/nessus/text_output.c
trunk/openvas-client/openvasclient-mkcert.in
Log:
* openvasclient-mkcert.in: Renamed Nessus to OpenVAS and
removed NessusWX-specific stuff.
* nessus/html_graph_output.c (print_data_with_links): Renamed
Nessus to OpenVAS.
* nessus/html_output.c (print_data_with_links, summary_to_file):
Renamed Nessus to OpenVAS.
* nessus/latex_output.c (latex_print_header, latex_introduction_a,
latex_introduction_b, latex_introduction_c, latex_introduction_d,
latex_introduction_e, latex_conclusion):
Renamed Nessus to OpenVAS.
* nessus/text_output.c (arglist_to_text): Renamed Nessus
to OpenVAS.
* include/config32.h: Removed. This file isn't used
anywhere.
Modified: trunk/openvas-client/ChangeLog
===================================================================
--- trunk/openvas-client/ChangeLog 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/ChangeLog 2008-09-28 22:49:28 UTC (rev 1462)
@@ -1,3 +1,25 @@
+2008-09-28 Jan-Oliver Wagner <jan-oliver.wagner at intevation.de>
+
+ * openvasclient-mkcert.in: Renamed Nessus to OpenVAS and
+ removed NessusWX-specific stuff.
+
+ * nessus/html_graph_output.c (print_data_with_links): Renamed
+ Nessus to OpenVAS.
+
+ * nessus/html_output.c (print_data_with_links, summary_to_file):
+ Renamed Nessus to OpenVAS.
+
+ * nessus/latex_output.c (latex_print_header, latex_introduction_a,
+ latex_introduction_b, latex_introduction_c, latex_introduction_d,
+ latex_introduction_e, latex_conclusion):
+ Renamed Nessus to OpenVAS.
+
+ * nessus/text_output.c (arglist_to_text): Renamed Nessus
+ to OpenVAS.
+
+ * include/config32.h: Removed. This file isn't used
+ anywhere.
+
2008-09-25 Michael Wiegand <michael.wiegand at intevation.de>
Post release version bump.
Deleted: trunk/openvas-client/include/config32.h
===================================================================
--- trunk/openvas-client/include/config32.h 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/include/config32.h 2008-09-28 22:49:28 UTC (rev 1462)
@@ -1,113 +0,0 @@
-/* Nessus
- * Copyright (C) 1998 - 1999 Renaud Deraison
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
-
-/*
- * GENERAL CONFIGURATION FOR THE WIN32 CLIENT
- */
-
-/*
- * define this if you want to see some useful debug
- * messages comming from Nessus
- */
-#undef DEBUG
-
-/*
- * define this if you want to spot a particular
- * problem, else don't, because it throws a lot
- * of garbage to the screen
- */
-#undef DEBUGMORE
-
-
-/*
- * The default port on which nessusd
- * will be listenning
- */
-#define DEFAULT_PORT 3001
-
-/*
- * How much time before closing
- * the connection if nothing comes
- * from the client ? (in secs)
- */
-#define CLIENT_TIMEOUT 300
-
-/*
- * How much time before killing
- * a plugin ? (in secs)
- * (if you have a slow computer or a slow
- * network connection, set it to 320 or more)
- */
-
-#define PLUGIN_TIMEOUT 160
-
-
-/*
- * Shall the server log EVERYTHING ?
- */
-
-#undef LOGMORE
-
-/*
- * Shall the server log the whole attack ?
- */
-
-#undef LOG_WHOLE_ATTACK
-
-/*
- * Host specs.
- *
- * Set this if you are running OpenBSD < 2.1 or all FreeBSD or
- * all netBSD, or BSDi < 3.0
- *
- * If you have run this script as root, then it should be correctly
- * set up
- *
- */
-#undef BSD_BYTE_ORDERING
-
-
-/*
- * NESSUS CLIENT SPECIFIC CONFIGURATION
- */
-
-/*
- * Build the client with GTK?
- */
-#define USE_GTK
-
-/*
- * How long before closing the
- * connection to the server if
- * it stays mute ?
- */
-#define SERVER_TIMEOUT 800
-
-
-
-
-#define GTK_VERSION 12
-
-#define NESS_COMPILER "(unknown)"
-#define NESS_OS_NAME "Windows 95/98/NT"
-#define NESS_OS_VERSION "(unknown)"
-
-#define PROGNAME "Nessus"
-#define NESSUS_VERSION "0.98.4"
-
Modified: trunk/openvas-client/nessus/html_graph_output.c
===================================================================
--- trunk/openvas-client/nessus/html_graph_output.c 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/nessus/html_graph_output.c 2008-09-28 22:49:28 UTC (rev 1462)
@@ -635,7 +635,7 @@
str++;
}
- fprintf(file, "Nessus ID : ");
+ fprintf(file, "OpenVAS ID : ");
fprint_link(file, "url_nessus", plugin_id);
}
Modified: trunk/openvas-client/nessus/html_output.c
===================================================================
--- trunk/openvas-client/nessus/latex_output.c 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/nessus/latex_output.c 2008-09-28 22:49:28 UTC (rev 1462)
@@ -97,7 +97,7 @@
fprintf(f, "\\ifx\\pdfoutput\\undefined\\else\\usepackage{times}\\fi\n");
fprintf(f, "\\usepackage{fancyhdr}\n");
fprintf(f, "\\pagestyle{fancy}\n");
- fprintf(f, "\\fancyhead[LE,RO]{\\textit{Nessus Report}}\n");
+ fprintf(f, "\\fancyhead[LE,RO]{\\textit{OpenVAS Report}}\n");
fprintf(f, "\\fancyfoot[LE,RO]{}\n");
/*
@@ -105,9 +105,9 @@
* table of contents
*/
fprintf(f, "\\pagenumbering{roman}\n");
- fprintf(f, "\\title{\\vspace*{100pt}\\Huge Report of a Nessus scan\\normalsize}\n");
+ fprintf(f, "\\title{\\vspace*{100pt}\\Huge Report of a OpenVAS scan\\normalsize}\n");
fprintf(f, "%%\n%% You might want to change this : \n%%\n");
- fprintf(f, "\\author{Nessus Security Scanner}\n");
+ fprintf(f, "\\author{OpenVAS Security Scanner}\n");
fprintf(f, "\\begin{document}\n");
fprintf(f, "\\maketitle\n");
fprintf(f, "\\newpage\n");
@@ -143,7 +143,7 @@
int num_of_hosts = arglist_length(hosts);
fprintf(f, "\\newpage\n");
fprintf(f, "\\section*{Introduction}\n");
- fprintf(f, "In this test, Nessus has tested %d host",num_of_hosts);
+ fprintf(f, "In this test, OpenVAS has tested %d host",num_of_hosts);
if(num_of_hosts > 1)fprintf(f, "s");
fprintf(f," and none of the vulnerabilities tested were present on this ");
fprintf(f,"network ");
@@ -157,7 +157,7 @@
fprintf(f, "complete safety !}. Security Scanners can not test things such as home made ");
fprintf(f, "CGIs, so if you want the garantee that you network is secure, we recommand ");
fprintf(f, "that you check these things manually.\\\\\n");
- fprintf(f, "However, your network was given the highest mark that Nessus can give, ");
+ fprintf(f, "However, your network was given the highest mark that OpenVAS can give, ");
fprintf(f, "that is a A (worst being E). Congratulations !");
}
@@ -170,7 +170,7 @@
int num_of_hosts = arglist_length(hosts);
fprintf(f, "\\newpage\n");
fprintf(f, "\\section*{Introduction}\n");
- fprintf(f, "In this test, Nessus has tested %d host", num_of_hosts);
+ fprintf(f, "In this test, OpenVAS has tested %d host", num_of_hosts);
if(num_of_hosts > 1)fprintf(f, "s");
fprintf(f, " and found %d security holes, %d warnings and %d notes that can eventually help a cracker ", holes, warnings, notes);
fprintf(f, "to break into your network. You should have a close look at them and ");
@@ -188,7 +188,7 @@
fprintf(f,"list of what was tested).\\\\\n");
}
fprintf(f, "which is a very good thing.\\\\\n");
- fprintf(f, "On the overall, Nessus has given to the security of this network the mark B. (A being the best ");
+ fprintf(f, "On the overall, OpenVAS has given to the security of this network the mark B. (A being the best ");
fprintf(f, "and E being the worst).");
}
@@ -202,7 +202,7 @@
int num_of_hosts = arglist_length(hosts);
fprintf(f, "\\newpage\n");
fprintf(f, "\\section*{Introduction}\n");
- fprintf(f, "In this test, Nessus has tested %d host", num_of_hosts);
+ fprintf(f, "In this test, OpenVAS has tested %d host", num_of_hosts);
if(num_of_hosts > 1)fprintf(f, "s");
fprintf(f, " and found %d security holes, %d warnings an %d notes that can eventually help a cracker ", holes, warnings, notes);
fprintf(f, "to break into your network. You should have a close look at them and ");
@@ -226,7 +226,7 @@
fprintf(f,"list of what was tested).\\\\\n");
}
fprintf(f, " which is a very good thing.\\\\\n");
- fprintf(f, "On the overall, Nessus has given to the security of this network the mark C. (A being the best ");
+ fprintf(f, "On the overall, OpenVAS has given to the security of this network the mark C. (A being the best ");
fprintf(f, "and E being the worst).");
return 0;
}
@@ -238,7 +238,7 @@
int num_of_hosts = arglist_length(hosts);
fprintf(f, "\\newpage\n");
fprintf(f, "\\section*{Introduction}\n");
- fprintf(f, "In this test, Nessus has tested %d host", num_of_hosts);
+ fprintf(f, "In this test, OpenVAS has tested %d host", num_of_hosts);
if(num_of_hosts > 1)fprintf(f, "s");
fprintf(f, " and found \\textbf{%d severe security holes}, as well as %d security warnings and %d notes.", holes, warnings, notes);
fprintf(f, "These problems can easily be used to break ");
@@ -260,7 +260,7 @@
fprintf(f, "(see Appendix A and B page \\pageref{appendix_a} and page \\pageref{appendix_b} for the exhaustive ");
fprintf(f,"list of what was tested).\\\\\n");
}
- fprintf(f, "On the overall, Nessus has given to the security of this network the mark D. (A being the best ");
+ fprintf(f, "On the overall, OpenVAS has given to the security of this network the mark D. (A being the best ");
fprintf(f, "and E being the worst). There is room for improvement, and ");
fprintf(f, "\\textbf{we strongly suggest that you take the appropriate measures to ");
fprintf(f, "solve these problems \\textit{as soon as possible}}\n");
@@ -273,7 +273,7 @@
int num_of_hosts = arglist_length(hosts);
fprintf(f, "\\newpage\n");
fprintf(f, "\\section*{Introduction}\n");
- fprintf(f, "In this test, Nessus has tested %d host", num_of_hosts);
+ fprintf(f, "In this test, OpenVAS has tested %d host", num_of_hosts);
if(num_of_hosts > 1)fprintf(f, "s");
fprintf(f, " and found \\textbf{%d severe security holes}, as well as %d security warnings and %d notes.", holes, warnings, notes);
fprintf(f, "These problems can easily be used to break ");
@@ -295,7 +295,7 @@
fprintf(f,"list of what was tested).\\\\\n");
}
- fprintf(f, "On the overall, Nessus has given to the security of this network the mark E ");
+ fprintf(f, "On the overall, OpenVAS has given to the security of this network the mark E ");
fprintf(f, "because of the number of vulnerabilities found. A script kid should be ");
fprintf(f, "able to break into your network rather easily.\\\\\n");
fprintf(f, "There is room for improvement, and ");
@@ -439,7 +439,7 @@
{
fprintf(f, "\\newpage\n");
fprintf(f, "\\section*{Conclusion}\n");
- fprintf(f, "A security scanner, such as Nessus, is not a guarantee ");
+ fprintf(f, "A security scanner, such as OpenVAS, is not a guarantee ");
fprintf(f, "of the security of your network.\\\\\n");
fprintf(f, "A lot of factors can not be tested by a security scanner : ");
fprintf(f, "the practices of the users of the network, the home-made ");
Modified: trunk/openvas-client/nessus/text_output.c
===================================================================
--- trunk/openvas-client/nessus/text_output.c 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/nessus/text_output.c 2008-09-28 22:49:28 UTC (rev 1462)
@@ -106,7 +106,7 @@
return(-1);
}
- fprintf(file, "Nessus Scan Report\n");
+ fprintf(file, "OpenVAS Scan Report\n");
fprintf(file, "------------------\n\n\n\n");
Modified: trunk/openvas-client/openvasclient-mkcert.in
===================================================================
--- trunk/openvas-client/openvasclient-mkcert.in 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/openvasclient-mkcert.in 2008-09-28 22:49:28 UTC (rev 1462)
@@ -40,7 +40,7 @@
# initialize gettext
. gettext.sh
- export TEXTDOMAIN=nessus-scripts
+ export TEXTDOMAIN=openvas-scripts
export TEXTDOMAINDIR=@datadir@/locale
else
@@ -72,7 +72,7 @@
{
clear
echo "-------------------------------------------------------------------------------"
-gettext " Creation Nessus SSL Client Certificate"; echo
+gettext " Creation OpenVAS SSL Client Certificate"; echo
echo "-------------------------------------------------------------------------------"
echo
}
@@ -112,16 +112,16 @@
-NESSUSPRIV="$localstatedir/nessus/CA"
-NESSUSPUB="$sharedstatedir/nessus/CA"
+NESSUSPRIV="$localstatedir/openvas/CA"
+NESSUSPUB="$sharedstatedir/openvas/CA"
while [ ! -d "$NESSUSPRIV" ]; do
- gettext "Nessus server 'private' directory: "
+ gettext "OpenVAS server 'private' directory: "
read NESSUSPRIV
done
while [ ! -d "$NESSUSPUB" ]; do
- gettext "Nessus server 'public' directory: "
+ gettext "OpenVAS server 'public' directory: "
read NESSUSPUB
done
@@ -130,13 +130,13 @@
while [ ! -f "$CAKEY" ]; do
eval_gettext "\$CAKEY: not found or not a file."
- gettext "Nessus CA private key: "
+ gettext "OpenVAS CA private key: "
read CAKEY
done
while [ ! -f "$CACERT" ]; do
eval_gettext "\$CACERT: not found or not a file."
- gettext "Nessus CA certificate: "
+ gettext "OpenVAS CA certificate: "
read CACERT
done
@@ -148,12 +148,12 @@
R=x
while [ "$R" != `gettext "y"` -a "$R" != `gettext "n"` ]; do
- gettext "Do you want to register the users in the Nessus server as soon as you create their certificates? (y/n): "
+ gettext "Do you want to register the users in the OpenVAS server as soon as you create their certificates? (y/n): "
read R
done
if [ "$R" = `gettext "y"` ]; then
- USERSDIR=$localstatedir/nessus/users
+ USERSDIR=$localstatedir/openvas/users
while [ ! -d "$USERSDIR" ]; do
eval_gettext "\$USERSDIR: not a directory."; echo
gettext "Users directory? "
@@ -170,7 +170,7 @@
mkdir $BASEDIR || exit 1
-gettext "This script will now ask you the relevant information to create the SSL client certificates for Nessus."; echo
+gettext "This script will now ask you the relevant information to create the SSL client certificates for OpenVAS."; echo
gettext "Client certificates life time in days [365]: "; read x
DFL_CERT_LIFETIME=${x:-365}
@@ -195,9 +195,9 @@
RANDFILE = $HOME/.rnd
#
[ ca ]
-default_ca = NessusCA
+default_ca = OpenVASCA
-[ NessusCA ]
+[ OpenVASCA ]
dir = $BASEDIR # Where everything is kept
certs = \$dir # Where the issued certs are kept
crl_dir = \$dir # Where the issued crl are kept
@@ -334,7 +334,7 @@
while [ "$ANOTHER" != `gettext "n"` ]; do
PSEUDO=""
while [ -z "$PSEUDO" ]; do
- eval_gettext "User \${Hash}\$I name \${Bo}e.g. Nessus username\${Bc}: "
+ eval_gettext "User \${Hash}\$I name \${Bo}e.g. OpenVAS username\${Bc}: "
read PSEUDO
CERTFILE="$BASEDIR/cert_$PSEUDO.pem"
KEYFILE="$BASEDIR/key_$PSEUDO.pem"
@@ -343,7 +343,7 @@
if [ -f "$CERTFILE" -o -f "$KEYFILE" -o -f "$DNFILE" ]; then
A=""
while [ -z "$A" ]; do
- gettext "Certificate, key or Nessus DN file(s) already exist."; echo
+ gettext "Certificate, key or OpenVAS DN file(s) already exist."; echo
gettext "Do you want to go on and overwrite it/them? (y/n) "
read A
if [ "$A" = `gettext "n"` ]; then PSEUDO=""; fi
@@ -385,15 +385,9 @@
openssl req -config $BASEDIR/stdC.cnf -new -key $KEYFILE -out $REQFILE
# Sign the client certificate
- openssl ca -config $BASEDIR/stdC.cnf -name NessusCA -batch -days $CERT_LIFETIME -in $REQFILE -out $CERTFILE
+ openssl ca -config $BASEDIR/stdC.cnf -name OpenVASCA -batch -days $CERT_LIFETIME -in $REQFILE -out $CERTFILE
- # Create export file for NessusWX
- NWX_CERTFILE=$BASEDIR/cert_nessuswx_$PSEUDO.pem
- cp $CERTFILE $NWX_CERTFILE
- cat $KEYFILE >> $NWX_CERTFILE
-
chmod a+r $CERTFILE
- chmod a+r $NWX_CERTFILE
if [ ! -z "$USERSDIR" ]; then
@@ -413,10 +407,10 @@
echo
gettext "User rules"; echo
echo "----------"
- eval_gettext "nessusd has a rules system which allows you to restrict the hosts that \$login has the right to test."; echo
+ eval_gettext "openvasd has a rules system which allows you to restrict the hosts that \$login has the right to test."; echo
gettext "For instance, you may want him to be able to scan his own host only."; echo
echo
- gettext "Please see the nessus-adduser(8) man page for the rules syntax."; echo
+ gettext "Please see the openvas-adduser(8) man page for the rules syntax."; echo
echo
gettext "Enter the rules for this user, and hit ctrl-D once you are done:"; echo
@@ -457,7 +451,7 @@
mkdir -p "$E"
chmod 700 "$E"
fi
- gettext "User added to Nessus."; echo
+ gettext "User added to OpenVAS."; echo
fi
gettext "Another client certificate? (y/n) "
More information about the Openvas-commits
mailing list
--- trunk/openvas-client/nessus/html_output.c 2008-09-28 04:42:28 UTC (rev 1461)
+++ trunk/openvas-client/nessus/html_output.c 2008-09-28 22:49:28 UTC (rev 1462)
@@ -54,7 +54,7 @@
*/
/*
* print URL linking to CVE/BID/Nessus database to file.
* '%s' in urlfmt (from preferences) will be replaced by
* item IDs (or their parts split at minus characters).
* '%%' will insert a percent character.
@@ -195,7 +195,7 @@
str++;
}
- fprintf(file, "Nessus ID : ");
+ fprintf(file, "OpenVAS ID : ");
fprint_link(file, "url_nessus", plugin_id);
}
@@ -516,7 +516,7 @@
fprintf(file, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n");
fprintf(file, "<HTML>\n");
fprintf(file, " <HEAD>\n");
- fprintf(file, " <TITLE>Nessus Scan Report</TITLE>\n");
+ fprintf(file, " <TITLE>OpenVAS Scan Report</TITLE>\n");
fprintf(file, " <meta http-equiv=\"Content-Type\" content=\"text/html; charset=\"iso-8859-1\">\n");
fprintf(file, " <style type=\"text/css\">\n");
fprintf(file, " <!--\n");
@@ -556,7 +556,7 @@
fprintf(file, "<table bgcolor=\"#a1a1a1\" border=0 cellpadding=0 cellspacing=0 width=\"95%%\">\n");
fprintf(file, "<tbody>\n\t<tr><td>\n<table border=0 cellpadding=2 cellspacing=1 width=\"100%%\">\n");
fprintf(file, "\t<tbody>\n <tr>\n");
- fprintf(file, "\t<td class=title>Nessus Scan Report</td></tr>\n");
+ fprintf(file, "\t<td class=title>OpenVAS Scan Report</td></tr>\n");
fprintf(file, " <tr>\n\t<td class=content>This report gives details on hosts that were tested\n");
fprintf(file, "\t\tand issues that were found. Please follow the recommended\n");
fprintf(file, "\t\tsteps and procedures to eradicate these threats.\n");
@@ -54,7 +54,7 @@
*/
/*
- * print URL linking to CVE/BID/Nessus database to file.
+ * print URL linking to CVE/BID/OpenVAS database to file.
* '%s' in urlfmt (from preferences) will be replaced by
* item IDs (or their parts split at minus characters).
Modified: trunk/openvas-client/nessus/latex_output.c
===================================================================